{{/*
Common labels
*/}}
{{- define "iam.labels" -}}
{{ include "iam-utils.labels" . }}
{{- end -}}

{{/*
Selector labels
*/}}
{{- define "iam.selectorLabels" -}}
{{ include "iam-utils.selectorLabels" . }}
{{- end -}}


{{/*
    - Generates the name of the IAM Role
    - Checks if the length of the IAM Role
    is within range of the number of characters allowed
    - If not errors out
*/}}
{{- define "iam.roleName" -}}
{{- $roleName:= printf "mcs2-app-%s" (include "iam-utils.externalNamingPrefix" . ) -}}
{{- $lenRoleName := $roleName | len | float64 -}}
{{- if gt $lenRoleName .Values.maxNameLength -}}
{{- printf "\nThe generated roleName %s is greater than the allowed number of characters %f." $roleName .Values.maxNameLength | fail -}}
{{- else -}}
{{- printf "%s" $roleName -}}
{{- end -}}
{{- end -}}

{{/*
Generates the list of DynamoDB tables used by the DAX IAM role
*/}}
{{- define "iam.daxConfig.tables" -}}
{{- if .Values.daxRole -}}
{{- range $index, $table := .Values.daxConfig }}
- name: DYNAMODB_TABLE_{{ $index }}
  valueFrom:
    configMapKeyRef:
      name: {{ (printf "%s-%s-arn" (get $table "dynamodbReleaseName") (get $table "dynamodbAlias")) }}
      key: ARN
{{- end -}}
{{- end -}}
{{- end -}}

{{/*
   Define the iam arn configMap params if existingInfraOverrides flag is set.
   The arn configmap is created when deploy-iam.sh is called. Since
   for overrides, we need to populate the same for the existing infrastructure.
*/}}
{{- define "iam.arnConfigMapParams" -}}
{{- if not ( and .Values.existingInfraOverrides.ARN .Values.existingInfraOverrides.roleName ) }}
{{ printf ("\n\nIf you have set \".Values.existingInfraOverrides.enable\" as true then please provide a value for the existing iam role ARN and roleName") | fail }}
{{- end }}
ARN: {{ .Values.existingInfraOverrides.ARN }}
RoleName: {{ .Values.existingInfraOverrides.roleName }}
{{- end -}}